# ====================================================================
#     build bex1D executables
#            Copyright (c) 2004-2006  by A. Miyoshi, Univ. Tokyo
# ====================================================================

# ----- executables to be built ------------------
LSTEXE = bx1fitPlls bx1HRsol bx1VIBsol bx1S2HRsol

# ----- Operating System dependents ----------------------------------
RM = rm -f
XO = o
XA = a
TMPF =
#              (for Windows only)
#RM = del
#XO = obj
#XA = lib
#              (for Djgpp/Windows only - files removed @ target=clean)
#TMPF = $(LSTEXE)

# ----- C++ and Fortran compilers -------------------------------
#  Solaris Spark                :  CC   f77
#  GNU - Djgpp                  :  gpp  g77
#  GNU (other)                  :  g++  g77
#  Intel Linux v <= 7.1 (32bit) :  icc  ifc
#                       (64bit) :  ecc  efc
#           v >= 8.0 (32/64bit) :  icc  ifort
#  Intel Windows                :  icl  ifort

OPTF = -O
#              (Intel/Windows only)
#OPTF = -O2

#CPCMP = CC $(OPTF)
CPCMP = g++ $(OPTF)
#CPCMP = gpp $(OPTF)
#CPCMP = icc $(OPTF)
#CPCMP = ecc $(OPTF)
#CPCMP = icl $(OPTF)

#F7CMP = f77 $(OPTF)
F7CMP = g77 $(OPTF)
#F7CMP = ifc $(OPTF)
#F7CMP = efc $(OPTF)
#F7CMP = ifort $(OPTF)

# ----- Libraries ----------------------------------------------------

# ----- LAPACK/BLAS file ----------------------------------------
#                             (build a part of LAPACK/BLAS)
LPKSBE = lapack_dsbev.$(XA)
LPKPOS = lapack_dposv.$(XA)
LPKHBE = lapack_zhbev.$(XA)
#                             (use pre-build LAPACK/BLAS)
#LPKSBE = wcpp_dsbev.$(XO)
#LPKPOS = wcpp_dposv.$(XO)
#LPKHBE = wcpp_zhbev.$(XO)

# ----- Fortran run-time libraries ------------------------------
# (required when building a part of LAPACK/BLAS)
#                                       (Solaris Spark)
#LLAPCK = -lfsu -lsunmath
#                                       (GNU compilers)
LLAPCK = -lg2c
#                                       (Intel/Linux v <= 7.1)
#LLAPCK = -lF90 -lIEPCF90
#                                       (Intel/Linux v = 8.0)
#LLAPCK = -L/opt/intel_fc_80/lib -lifcore
#                                       (Intel/Linux v = 9.0)
#LLAPCK = -L/opt/intel/fc/9.0/lib -lifcore
#                                       (Intel/Windows)
#LLAPCK =

# ----- pre-built LAPACK/BLAS -----------------------------------
#                                            (g77-built)
#LLAPCK = -llapack -lblas -lg2c
#                                            (intel MKL - 32bit)
#MKLLDR = /opt/intel/mkl70/lib/32
#MKLLDR = /opt/intel/mkl72/lib/32
#LLAPCK = -L$(MKLLDR) -lmkl_lapack -lmkl_ia32 -lguide -lpthread
#                                            (intel MKL - 64bit)
#MKLLDR = /opt/intel/mkl70/lib/64
#MKLLDR = /opt/intel/mkl72/lib/64
#LLAPCK = -L$(MKLLDR) -lmkl_lapack -lmkl_ipf -lguide -lpthread

# ===== no need to edit below in usual circumstances =====================

LOBJLL = libnumLls.$(XO) libbasIOstr.$(XO) $(LPKPOS)
HEADLL = libnumLls.h libbasIOstr.h lapack_dposv/wcpp_dposv.h

LOBJPS = libbx1PS.$(XO) libbx1com.$(XO) libbasIOstr.$(XO) $(LPKSBE)
HEADPS = libbx1PS.h libbx1com.h libbasIOstr.h lapack_dsbev/wcpp_dsbev.h

LOBJFS = libbx1FS.$(XO) libbx1com.$(XO) libbasIOstr.$(XO) $(LPKHBE)
HEADFS = libbx1FS.h libbx1com.h libbasIOstr.h lapack_zhbev/wcpp_zhbev.h

LOBJCP2 = libbx1CP2.$(XO) libbx1com.$(XO) libbasIOstr.$(XO) $(LPKSBE)
HEADCP2 = libbx1CP2.h libbx1com.h libbasIOstr.h lapack_dsbev/wcpp_dsbev.h

all: $(LSTEXE)

bx1fitPlls : bx1fitPlls.cc bx1fitPlls.h $(HEADLL) $(LOBJLL)
	$(CPCMP) bx1fitPlls.cc $(LOBJLL) $(LLAPCK) -o bx1fitPlls

bx1VIBsol : bx1VIBsol.cc bx1VIBsol.h $(HEADPS) $(LOBJPS)
	$(CPCMP) bx1VIBsol.cc $(LOBJPS) $(LLAPCK) -o bx1VIBsol

bx1HRsol : bx1HRsol.cc bx1HRsol.h $(HEADFS) $(LOBJFS)
	$(CPCMP) bx1HRsol.cc $(LOBJFS) $(LLAPCK) -o bx1HRsol

bx1S2HRsol : bx1S2HRsol.cc bx1S2HRsol.h $(HEADCP2) $(LOBJCP2)
	$(CPCMP) bx1S2HRsol.cc $(LOBJCP2) $(LLAPCK) -o bx1S2HRsol

libnumLls.$(XO) : libnumLls.cc $(HEADLL)
	$(CPCMP) -c libnumLls.cc

libbx1PS.$(XO) : libbx1PS.cc $(HEADPS)
	$(CPCMP) -c libbx1PS.cc

libbx1FS.$(XO) : libbx1FS.cc $(HEADFS)
	$(CPCMP) -c libbx1FS.cc

libbx1CP2.$(XO) : libbx1CP2.cc $(HEADCP2)
	$(CPCMP) -c libbx1CP2.cc

libbx1com.$(XO) : libbx1com.cc libbx1com.h libbasIOstr.h
	$(CPCMP) -c libbx1com.cc

libbasIOstr.$(XO) : libbasIOstr.cc libbasIOstr.h
	$(CPCMP) -c libbasIOstr.cc

lapack_dsbev.a : lapack_dsbev/*.f lapack_dsbev/wcpp_dsbev.cc lapack_dsbev/wcpp_dsbev.h
	cd lapack_dsbev; \
	$(F7CMP) -c *.f; \
	$(CPCMP) -c wcpp_dsbev.cc; \
	ar cr ../$(LPKSBE) *.$(XO); \
	$(RM) *.$(XO); \
	cd ..

lapack_dsbev.lib : lapack_dsbev/*.f lapack_dsbev/wcpp_dsbev.cc lapack_dsbev/wcpp_dsbev.h
	cd lapack_dsbev
	$(F7CMP) -c *.f
	$(CPCMP) -c wcpp_dsbev.cc
	lib /OUT:..\$(LPKSBE) *.$(XO)
	$(RM) *.$(XO)
	cd ..

wcpp_dsbev.o : lapack_dsbev/wcpp_dsbev.cc lapack_dsbev/wcpp_dsbev.h
	cd lapack_dsbev; \
	$(CPCMP) -c wcpp_dsbev.cc -o ../wcpp_dsbev.o; \
	cd ..

wcpp_dsbev.obj : lapack_dsbev/wcpp_dsbev.cc lapack_dsbev/wcpp_dsbev.h
	cd lapack_dsbev
	$(CPCMP) -c wcpp_dsbev.cc -o ..\wcpp_dsbev.obj
	cd ..

lapack_dposv.a : lapack_dposv/*.f lapack_dposv/wcpp_dposv.cc lapack_dposv/wcpp_dposv.h
	cd lapack_dposv; \
	$(F7CMP) -c *.f; \
	$(CPCMP) -c wcpp_dposv.cc; \
	ar cr ../$(LPKPOS) *.$(XO); \
	$(RM) *.$(XO); \
	cd ..

lapack_dposv.lib : lapack_dposv/*.f lapack_dposv/wcpp_dposv.cc lapack_dposv/wcpp_dposv.h
	cd lapack_dposv
	$(F7CMP) -c *.f
	$(CPCMP) -c wcpp_dposv.cc
	lib /OUT:..\$(LPKPOS) *.$(XO)
	$(RM) *.$(XO)
	cd ..

wcpp_dposv.o : lapack_dposv/wcpp_dposv.cc lapack_dposv/wcpp_dposv.h
	cd lapack_dposv; \
	$(CPCMP) -c wcpp_dposv.cc -o ../wcpp_dposv.o; \
	cd ..

wcpp_dposv.obj : lapack_dposv/wcpp_dposv.cc lapack_dposv/wcpp_dposv.h
	cd lapack_dposv
	$(CPCMP) -c wcpp_dposv.cc -o ..\wcpp_dposv.obj
	cd ..

lapack_zhbev.a : lapack_zhbev/*.f lapack_zhbev/wcpp_zhbev.cc lapack_zhbev/wcpp_zhbev.h
	cd lapack_zhbev; \
	$(F7CMP) -c *.f; \
	$(CPCMP) -c wcpp_zhbev.cc; \
	ar cr ../$(LPKHBE) *.$(XO); \
	$(RM) *.$(XO); \
	cd ..

lapack_zhbev.lib : lapack_zhbev/*.f lapack_zhbev/wcpp_zhbev.cc lapack_zhbev/wcpp_zhbev.h
	cd lapack_zhbev
	$(F7CMP) -c *.f
	$(CPCMP) -c wcpp_zhbev.cc
	lib /OUT:..\$(LPKHBE) *.$(XO)
	$(RM) *.$(XO)
	cd ..

wcpp_zhbev.o : lapack_zhbev/wcpp_zhbev.cc lapack_zhbev/wcpp_zhbev.h
	cd lapack_zhbev; \
	$(CPCMP) -c wcpp_zhbev.cc -o ../wcpp_zhbev.o; \
	cd ..

wcpp_zhbev.obj : lapack_zhbev/wcpp_zhbev.cc lapack_zhbev/wcpp_zhbev.h
	cd lapack_zhbev
	$(CPCMP) -c wcpp_zhbev.cc -o ..\wcpp_zhbev.obj
	cd ..

clean:
	$(RM) *.$(XO) *.$(XA) $(TMPF)

