/* ======================================================================
     "libbx1FS.cc"
       - basis expansion library for Fourier series potential and
          free rotor (Fourier series) basis
             Copyright (c) 2004-2005  by A. Miyoshi, Univ. Tokyo
                         created: Sept. 13, 2004   solHRxp.c Rev. 0.10
                          edited: Nov.  29, 2004   solHRxp.c Rev. 0.11
                     last edited: July  11, 2005   solHRxp.c Rev. 0.12
      created based on solHRxp.c: Oct.  12, 2005
                          edited: Oct.  13, 2005   Rev. 0.10
                     last edited: Jan.   7, 2007   Rev. 0.11
 ====================================================================== */

#include "libbx1FS.h"

/* ======================================================================
     Fourier series potential
 ====================================================================== */

fourSeries::fourSeries()                          // --- constructor ---
 { clear(); maxAbsOrder = 0; }

void fourSeries::finishSetting() {  // --- finish after term setting ---
  iterator p;
  maxAbsOrder = 0;
  for (p = begin(); p != end(); p++) {
    if (abs(p->first) > maxAbsOrder) { maxAbsOrder = abs(p->first); }
  }
}

/* ======================================================================
     free rotor basis set
 ====================================================================== */

                                  // --- constructors / initializers ---
basisFreeRotor::basisFreeRotor() { clear(); }
void basisFreeRotor::clear()
 { maxAbsQntNbr = 0; rotB = 0.; potE.clear(); nSpinW.clear(); }

                                      // --- solve for nBasis = nbas ---
int basisFreeRotor::solve(int maqn) {
  maxAbsQntNbr = maqn;
  int n = maxAbsQntNbr * 2 + 1, kd = potE.maxAbsOrder;
  int iqn, jqn, irow, jcol, info;
  double a0 = potE[0];
  // --- diagonal elements
  for (iqn = -maxAbsQntNbr; iqn <= maxAbsQntNbr; iqn++) {
    jcol = iqn + maxAbsQntNbr; irow = kd;
    ab[jcol][irow] = complex<double>(a0 + rotB * iqn * iqn, 0.);
  }
  // --- off-diagonal elements
  for (iqn = -maxAbsQntNbr; iqn <= maxAbsQntNbr; iqn++) {
    for (jqn = iqn + 1; jqn <= iqn + kd; jqn++) {
      jcol = jqn + maxAbsQntNbr; irow = iqn - jqn + kd;
      ab[jcol][irow] = complex<double>(potE[jqn - iqn] / 2.,
                                       potE[iqn - jqn] / 2.);
    }
  }
  info = lapack_zhbev('V', 'U', n, kd, (complex<double> **)ab, MXRWAB, w,
                     (complex<double> **)z, MXNBAS, work, rwork);
  if (info < 0) { cout << "ZHBEV: - invalid input.\n"; return ERRE; }
  else if (info > 0)
   { cout << "ZHBEV: - convergence failure.\n"; return ERRE; }
  return NORM;
}
                 // --- set eigen func in f[] and return its pointer ---
complex<double> *basisFreeRotor::eigenFunc(double x, int laqn) {
  int iq, nqn = laqn * 2 + 1, ib, nbf = maxAbsQntNbr * 2 + 1;
  complex<double> fv, czero(0., 0.);
  setBasisFunc(x);
  for (iq = 0; iq < nqn; iq++) {
    fv = czero;
    for (ib = 0; ib < nbf; ib++) { fv += z[iq][ib] * work[ib]; }
    f[iq] = fv;
  }
  return f;
}
                                 // --- set basis function in work[] ---
void basisFreeRotor::setBasisFunc(double x) {
  int qb, ib;
  double sq2pi = sqrt(2. * M_PI);
  complex<double> img1(0., 1.), iJth;
  for (qb = -maxAbsQntNbr; qb <= maxAbsQntNbr; qb++) {
    ib = qb + maxAbsQntNbr;
    iJth = img1 * (double)qb * x;
    work[ib] = exp(iJth) / sq2pi;
  }
}

